@@ -39,12 +39,8 @@ def override_dpy():
 
     #region message override
     async def send(self: discord.TextChannel, content=None, **kwargs) -> Message:
-        channel_id = self.id if not isinstance(self, commands.Context) else self.channel.id
-
-        if isinstance(self, (discord.Member, discord.User)) and self.dm_channel is None:
-                channel_id = (await self.create_dm()).id
-        
-        route = BetterRoute("POST", f"/channels/{channel_id}/messages")
+        channel = await self._get_channel()
+        route = BetterRoute("POST", f"/channels/{channel.id}/messages")
         
         r = None
         if kwargs.get("file") is None and kwargs.get("files") is None:
@@ -55,10 +51,11 @@ def override_dpy():
                 files = [kwargs.pop("file")]
             elif kwargs.get("files") is not None:
                 files = kwargs.pop("files")
+            
             payload = jsonifyMessage(content=content, **kwargs)
             r = await send_files(route, files=files, payload=payload, http=self._state.http)
         
-        msg = Message(state=self._state, channel=self if not isinstance(self, commands.Context) else self.channel, data=r)
+        msg = Message(state=self._state, channel=channel, data=r)
         if kwargs.get("delete_after") is not None:
             await msg.delete(delay=kwargs.get("delete_after"))
     
